package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.EtCouponClaimLogMapper;
import com.ruoyi.system.domain.EtCouponClaimLog;
import com.ruoyi.system.service.IEtCouponClaimLogService;

/**
 * 优惠券领取记录Service业务层处理
 * 
 * @author qzz
 * @date 2024-08-08
 */
@Service
public class EtCouponClaimLogServiceImpl implements IEtCouponClaimLogService 
{
    @Autowired
    private EtCouponClaimLogMapper etCouponClaimLogMapper;

    /**
     * 查询优惠券领取记录
     * 
     * @param claimId 优惠券领取记录主键
     * @return 优惠券领取记录
     */
    @Override
    public EtCouponClaimLog selectEtCouponClaimLogByClaimId(Long claimId)
    {
        return etCouponClaimLogMapper.selectEtCouponClaimLogByClaimId(claimId);
    }

    /**
     * 查询优惠券领取记录列表
     * 
     * @param etCouponClaimLog 优惠券领取记录
     * @return 优惠券领取记录
     */
    @Override
    public List<EtCouponClaimLog> selectEtCouponClaimLogList(EtCouponClaimLog etCouponClaimLog)
    {
        return etCouponClaimLogMapper.selectEtCouponClaimLogList(etCouponClaimLog);
    }

    /**
     * 新增优惠券领取记录
     * 
     * @param etCouponClaimLog 优惠券领取记录
     * @return 结果
     */
    @Override
    public int insertEtCouponClaimLog(EtCouponClaimLog etCouponClaimLog)
    {
        etCouponClaimLog.setCreateTime(DateUtils.getNowDate());
        return etCouponClaimLogMapper.insertEtCouponClaimLog(etCouponClaimLog);
    }

    /**
     * 修改优惠券领取记录
     * 
     * @param etCouponClaimLog 优惠券领取记录
     * @return 结果
     */
    @Override
    public int updateEtCouponClaimLog(EtCouponClaimLog etCouponClaimLog)
    {
        return etCouponClaimLogMapper.updateEtCouponClaimLog(etCouponClaimLog);
    }

    /**
     * 批量删除优惠券领取记录
     * 
     * @param claimIds 需要删除的优惠券领取记录主键
     * @return 结果
     */
    @Override
    public int deleteEtCouponClaimLogByClaimIds(Long[] claimIds)
    {
        return etCouponClaimLogMapper.deleteEtCouponClaimLogByClaimIds(claimIds);
    }

    /**
     * 删除优惠券领取记录信息
     * 
     * @param claimId 优惠券领取记录主键
     * @return 结果
     */
    @Override
    public int deleteEtCouponClaimLogByClaimId(Long claimId)
    {
        return etCouponClaimLogMapper.deleteEtCouponClaimLogByClaimId(claimId);
    }
}
